from setuptools import setup, find_packages

with open("README_PYPI.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="rggrader2",
    version="0.1.2",
    author="Ruangguru AI Team",
    author_email="ai@ruangguru.com",
    description="Submission tool for Ruangguru AI Bootcamp",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ruang-guru/ai-grader",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        "requests",
        "Pillow",
        "pandas"
    ],
)
